]> cloudbase.mooo.com Git - z180-stamp.git/blobdiff - avr/cli.c
Rename getenv_char() --> getenv_str()
[z180-stamp.git] / avr / cli.c
index aa2c38883b1f58fe230166aa11bc9e814b73c080..77876afb9687a4e9b53b522c26462cb18c6471a3 100644 (file)
--- a/avr/cli.c
+++ b/avr/cli.c
@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2014 Leo C. <erbl259-lmu@yahoo.de>
+ * (C) Copyright 2014-2016 Leo C. <erbl259-lmu@yahoo.de>
  *
  * (C) Copyright 2000
  * Wolfgang Denk, DENX Software Engineering, wd@denx.de.
@@ -177,7 +177,7 @@ char *process_macros(char *input, char *output)
                                if (c == '}') {
                                        /* Terminate variable name */
                                        *(inp-1) = '\0';
-                                       const char *envval = getenv_char(varname);
+                                       const char *envval = getenv_str(varname);
                                        *(inp-1) = '}';
                                        /* Copy into the line if it exists */
                                        if (envval != NULL)
@@ -210,7 +210,7 @@ char *process_macros(char *input, char *output)
  * WARNING:
  *
  * We must create a temporary copy of the command since the command we get
* may be the result from getenv_char(), which returns a pointer directly to
  * the environment data, which may change magicly when the command we run
  * creates or modifies environment variables (like "bootp" does).
  *
@@ -258,26 +258,29 @@ static int cli_run_command(const char *cmd, int flag)
                 */
                for (inquotes = 0, sep = str; *sep; sep++) {
                        if ((*sep == '\'') &&
-                           (sep != str) &&                             /* past string start */
-                           (*(sep - 1) != '\\'))               /* and NOT escaped */
+                           (sep != str) &&                                     /* past string start */
+                           (*(sep - 1) != '\\'))                       /* and NOT escaped */
                                inquotes = !inquotes;
 
                        if (!inquotes &&
-                           (*sep == ';' || *sep == '\n') &&    /* separator */
-                           (sep != str) &&                             /* past string start */
-                           (*(sep - 1) != '\\'))               /* and NOT escaped */
+                           (*sep == ';' || *sep == '\n'        /* separator */
+                                       || *sep == '#') &&                      /*   or start of comment */
+                           ((sep == str) ||                            /* string start */
+                           (*(sep - 1) != '\\')))                      /*   or NOT escaped */
                                break;
                }
 
-               /*
-                * Limit the token to data between separators
-                */
+               /* no more commands after unescaped '#' token */
+               if (*sep == '#')
+                       *sep = '\0';
+
+               /* Limit the token to data between separators */
                token = str;
                if (*sep) {
-                       str = sep + 1;  /* start of command for next pass */
+                       str = sep + 1;          /* start of command for next pass */
                        *sep = '\0';
                } else {
-                       str = sep;      /* no more commands for next pass */
+                       str = sep;                      /* no more commands for next pass */
                }
                debug_parser("token: \"%s\"\n", token);
 
@@ -385,27 +388,3 @@ void cli_loop(void)
                }
        }
 }
-
-
-command_ret_t do_run(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
-{
-       int i;
-       (void) cmdtp;
-
-       if (argc < 2)
-               return CMD_RET_USAGE;
-
-       for (i = 1; i < argc; ++i) {
-               char *arg;
-
-               arg = getenv_char(argv[i]);
-               if (arg == NULL) {
-                       printf_P(PSTR("## Error: \"%s\" is not set\n"), argv[i]);
-                       return CMD_RET_FAILURE;
-               }
-
-               if (run_command(arg, flag) != 0)
-                       return CMD_RET_FAILURE;
-       }
-       return CMD_RET_SUCCESS;
-}
@@ -210,7 +210,7 @@ char *process_macros(char *input, char *output)
  *
  * We must create a temporary copy of the command since the command we get
- * may be the result from getenv_char(), which returns a pointer directly to
+ * may be the result from getenv_str(), which returns a pointer directly to
  * the environment data, which may change magicly when the command we run
  * creates or modifies environment variables (like "bootp" does).